# CERT UEFI Support Library

The CERT UEFI Support Library is a Python package that 
wraps several third-party decompression libraries for 
working with UEFI files. It is also available as 
from [PyPI cert-uefi-support](https://pypi.org/project/cert-uefi-support/)

It is a required dependency for the `cert-uefi-parser` project
project, which can be installed from [PyPI cert-uefi-parser](https://pypi.org/project/cert-uefi-parser/) 
or from the [GitHub repository](https://github.com/cmu-sei/cert-uefi-parser).
